package com.caimei365.user.service;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.vo.ClubTemporaryVo;
import com.caimei365.user.model.vo.ClubVo;
import com.caimei365.user.model.vo.ServiceProviderVo;
import com.caimei365.user.model.vo.UserLoginVo;
import com.github.pagehelper.PageInfo;

import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
public interface SellerService {

    /**
     * 协销机构列表
     *
     * @param serviceProviderId 协销Id
     * @param status            机构状态
     * @param name              机构名字关键字（搜索用）
     * @return
     */
    ResponseJson<PageInfo<ClubVo>> getClubList(Integer serviceProviderId, Integer status, Integer type, String name, Integer userIdentity, Integer groupServiceId, Integer pageNum, Integer pageSize);

    /**
     * 协销登录(手机号，密码)
     *
     * @param mobile   手机号
     * @param password 密码
     * @param unionId  微信unionId
     * @return UserLoginVo
     */
    ResponseJson<UserLoginVo> passwordLogin(String mobile, String password, String unionId);

    /**
     * 待注册机构列表
     *
     * @param userId     协销用户id
     * @param searchName 搜索名称
     * @param pageNum    第几页
     * @param pageSize   一页多少条
     * @return ClubTemporaryVo
     */
    ResponseJson<PageInfo<ClubTemporaryVo>> temporaryClub(Integer userId, String searchName, Integer pageNum, Integer pageSize);

    /**
     * 修改待注册机构资料
     *
     * @param temporaryDto
     * @return
     */
    ResponseJson<String> modifyTemporaryClub(ClubTemporaryDto temporaryDto);

    /**
     * 删除待注册机构资料
     *
     * @param id 暂存数据id
     * @return
     */
    ResponseJson<String> deleteTemporaryClub(Integer id);

    /**
     * 所有的机构列表
     *
     * @param searchWord 搜索关键字
     */
    ResponseJson<PageInfo<ClubVo>> getAllClubList(String searchWord, int pageNum, int pageSize);

    /**
     * 协销个人中心
     *
     * @param userId 协销用户id
     */
    ResponseJson<ServiceProviderPo> getSellerHome(Integer userId);

    ResponseJson<List<ServiceProviderVo>> getServiceTeam(Integer spId,Integer status);
}
